SystemOrganization addCategory: #MOOCContactBook!
SystemOrganization addCategory: 'MOOCContactBook-Tests'!
SystemOrganization addCategory: 'MOOCContactBook-WebComponents'!

WAComponent subclass: #WebContact
	instanceVariableNames: 'contact'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MOOCContactBook-WebComponents'!

!WebContact commentStamp: 'RichardMyatt 7/29/2017 14:24' prior: 0!
A class which will allow us to edit the contacts.  This example is taken from the Pharo Mooc week 5.!

!WebContact class methodsFor: 'editing' stamp: 'RichardMyatt 7/29/2017 14:26'!
editContact: aContact
	"allow editing of the contact"

	^ self new
			setContact: aContact;
			yourself! !

!WebContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/29/2017 14:32'!
contact
	"answer with the value of the contact instance variable"

	^ contact! !

!WebContact methodsFor: 'initialization' stamp: 'RichardMyatt 7/29/2017 15:21'!
initialize
	"initialize our contact web component"

	super initialize.
	contact := MOOCContact new! !

!WebContact methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 14:52'!
renderButtonsOn: html
	"render the save and cancell buttons"

	html tbsFormGroup: [ 
			html tbsButtonGroup: [ 
					self 
							renderSubmitButtonOn: html;
							renderCancelButtonOn: html ] ]! !

!WebContact methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 14:56'!
renderCancelButtonOn: html
	"render the cancel button"

	html tbsButton 
			beDanger;
			cancelCallback: [ self answer: nil ];
			with: 'Cancel'! !

!WebContact methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 14:48'!
renderContentOn: html
	"render the page for editing of contacts"

	html tbsContainer: [ 
			html heading: 'Contact Editing'.
			html tbsForm with: [ 
					self renderFieldsOn: html.
					self renderButtonsOn: html ] ]! !

!WebContact methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 14:45'!
renderEmailFieldOn: html
	"render the email field"

	html tbsFormGroup: [ 
			html label: 'Email'.
			html emailInput 
					tbsFormControl;
					placeholder: 'your@email.eu';
					callback: [ :email | self contact email: email address ];
					value: (self contact email ifNil: '') ]! !

!WebContact methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 14:37'!
renderFieldsOn: html
	"render the table for editing"

	self renderFullnameFieldOn: html.
	self renderEmailFieldOn: html! !

!WebContact methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 14:46'!
renderFullnameFieldOn: html
	"render the fullname field"

	html tbsFormGroup: [ 
			html label: 'Fullname'.
			html textInput 
					tbsFormControl;
					placeholder: 'fullname';
					callback: [ :value | self contact fullname: value ];
					value: (self contact fullname ifNil: '') ]! !

!WebContact methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 14:54'!
renderSubmitButtonOn: html
	"render the save button"

	html tbsSubmitButton 
			beSuccess;
			bePrimary;
			callback: [ self answer: self contact ];
			with: 'Save'! !

!WebContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/29/2017 14:31'!
setContact: aContact
	"set the value of the contact instance variable"

	contact := aContact! !

WAComponent subclass: #WebContactBook
	instanceVariableNames: 'contactBook'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MOOCContactBook-WebComponents'!

!WebContactBook commentStamp: 'RichardMyatt 7/26/2017 19:41' prior: 0!
I am a Seaside web component.  This code is taken from the Pharo MOOC for a contact book application.  The name of the class has been changed since I had understood that WA should not be used for subclassed components.!

!WebContactBook class methodsFor: 'initialization' stamp: 'RichardMyatt 7/27/2017 18:56'!
initialize
	"register the component with the Seaside framework"

	(WAAdmin register: self asApplicationAt: 'contacts')
			addLibrary: JQ2DeploymentLibrary;
			addLibrary: TBSDeploymentLibrary! !

WebContactBook initialize!

!WebContactBook methodsFor: 'accessing' stamp: 'RichardMyatt 7/29/2017 15:12'!
addContact
	"add new contact by calling the editor"

	(self call: WebContact new)
			ifNotNil: [ :contact | contactBook addContact: contact ]! !

!WebContactBook methodsFor: 'accessing' stamp: 'RichardMyatt 7/26/2017 19:54'!
contactBook
	"answer with the value of the instance variable contactBook"

	^ contactBook ifNil: [ contactBook := MOOCContactBook createDemoContactBook ]! !

!WebContactBook methodsFor: 'accessing' stamp: 'RichardMyatt 7/26/2017 19:55'!
contacts
	"answer with the OrderedCollection of contacts"

	^ self contactBook contacts! !

!WebContactBook methodsFor: 'iteration' stamp: 'RichardMyatt 7/26/2017 19:57'!
contactsDo: aBlock
	"iterate over the OrderedCollection of contacts"

	self contacts do: aBlock! !

!WebContactBook methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 15:00'!
renderButtonsForContact: aContact on: html
	"render a table row of contacts"

	html tbsButtonGroup: [ 
			self 
					renderEditButtonForContact: aContact on: html;
					renderRemoveButtonForContact: aContact on: html ]! !

!WebContactBook methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 14:57'!
renderContact: aContact on: html
	"render a table row of contacts"

	html tableRow: [ 
			html
					tableData: aContact fullname;
					tableData: aContact email;
					tableData: [ self renderPhotoOf: aContact on: html ];
					tableData: [ self renderButtonsForContact: aContact on: html ] ]! !

!WebContactBook methodsFor: 'rendering' stamp: 'RichardMyatt 7/27/2017 19:24'!
renderContactsOn: html
	"Render a table of contacts"

	html tbsTable: [ 
			html tableHead: [
					html 
							tableHeading: 'Name';
							tableHeading: 'Email';
							tableHeading: 'Photo' ].
			self contactsDo: [ :contact | self renderContact: contact on: html ] ]! !

!WebContactBook methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 15:06'!
renderContentOn: html
	"Main entry point of the view.  Render both a title and the list
	 of contacts"
	
	html
			tbsContainer: [ 
					html heading: 'My Contact Book'.
					html tbsForm: [ 
							self renderContactsOn: html.
							self renderGlobalButtonsOn: html ] ]
	! !

!WebContactBook methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 15:25'!
renderEditButtonForContact: aContact on: html
	"render edit button"

	html tbsButton
			beSuccess;
			callback: [ self call: (WebContact editContact: aContact) ];
			with: 'Edit'! !

!WebContactBook methodsFor: 'rendering' stamp: 'RichardMyatt 7/29/2017 15:08'!
renderGlobalButtonsOn: html
	"render global buttons"
	
	html tbsButtonGroup: [ 
			html tbsButton 
					beSuccess;
					callback: [ self addContact ];
					with: 'New Contact' ]
	! !

!WebContactBook methodsFor: 'rendering' stamp: 'RichardMyatt 7/27/2017 19:27'!
renderPhotoOf: aContact on: html
	"render a table row of contacts"

	html image url: aContact gravatarUrl! !

!WebContactBook methodsFor: 'rendering' stamp: 'RichardMyatt 7/27/2017 19:37'!
renderRemoveButtonForContact: aContact on: html
	"render a table row of contacts"

	html tbsButton
			beDanger;
			callback: [ self contactBook removeContact: aContact ];
			with: 'Remove'! !

!WebContactBook methodsFor: 'updating' stamp: 'RichardMyatt 7/26/2017 19:50'!
updateRoot: anHtmlRoot
	"update the root to specify a title"

	super updateRoot: anHtmlRoot.
	anHtmlRoot title: 'Contact Book'! !

TestCase subclass: #MOOCContactTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MOOCContactBook-Tests'!

!MOOCContactTest commentStamp: 'RichardMyatt 7/25/2017 15:34' prior: 0!
A class to hold the tests for our contact application.  Taken from the Pharo MOOC.!

!MOOCContactTest methodsFor: 'tests' stamp: 'RichardMyatt 7/27/2017 19:16'!
testAddingOfContact
	"test that the method for adding a contact to the Contact Book
	 works in the expected way"

	| contactBook newContact |
	contactBook := MOOCContactBook createDemoContactBook.
	self assert: (contactBook contacts size = 4).
	
	newContact := MOOCContact newNamed: 'Steven Robers' email: 'steve.roberts@yahoo.com'.
	contactBook addContact: newContact.
	self assert: (contactBook contacts size = 5).
	self assert: (contactBook contacts includes: newContact)
	
	
	! !

!MOOCContactTest methodsFor: 'tests' stamp: 'RichardMyatt 7/25/2017 17:05'!
testCreation
	"test the creation of a contact"

	| contact |
	contact := MOOCContact newNamed: 'Marcus Denker' email: 'marcus.denker@intia.fr'.
	self assert: contact fullname = 'Marcus Denker'.
	self assert: contact email = 'marcus.denker@intia.fr'.! !

!MOOCContactTest methodsFor: 'tests' stamp: 'RichardMyatt 7/27/2017 19:17'!
testRemovingAContact
	"test that the method for adding a contact to the Contact Book
	 works in the expected way"

	| contactBook contact |
	contactBook := MOOCContactBook createDemoContactBook.
	contact := contactBook contacts detect: [ :each | (each fullname = 'Marcus Denker') & 
																		(each email = 'marcus.denker@inria.fr') ].
	self assert: (contactBook contacts size = 4).
	self assert: (contactBook contacts includes: contact).
	
	contactBook removeContact: contact.
	self assert: (contactBook contacts size = 3).
	self assert: (contactBook contacts includes: contact) not
	! !

Object subclass: #MOOCContact
	instanceVariableNames: 'fullname email'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MOOCContactBook'!

!MOOCContact commentStamp: 'RichardMyatt 7/25/2017 18:53' prior: 0!
An example taken from the Pharo MOOC.

I represent a person with a name and an email address. I'm usually
part of a contact book.!

!MOOCContact class methodsFor: 'instance creation' stamp: 'RichardMyatt 7/25/2017 18:41'!
newNamed: aNameString email: anEmailString
	"Create a new contact instance with a name and email"

	^ self new 
			fullname: aNameString;
			email: anEmailString;
			yourself! !

!MOOCContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 16:55'!
email
	"answer the email address of the contact"
	
	^ email! !

!MOOCContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 16:56'!
email: aString
	"set the email address of the contact"
	
	email := aString! !

!MOOCContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 16:53'!
fullname
	"answer the full name of the contact"
	
	^ fullname! !

!MOOCContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 16:55'!
fullname: aString
	"set the full name of the contact"
	
	fullname := aString ! !

!MOOCContact methodsFor: 'gravatar' stamp: 'RichardMyatt 7/27/2017 19:23'!
gravatarUrl
	"generate the gravatar url"

	^ 'http://www.gravatar.com/avatar/' , (MD5 hashMessage: email
			trimBoth asLowercase) hex , '.jpg'! !

!MOOCContact methodsFor: 'printing' stamp: 'RichardMyatt 7/25/2017 18:52'!
printOn: aStream
	"customise the printing of the MOOCContact object"
	
	super printOn: aStream.
	aStream
			nextPutAll: ' -- '; 
			nextPutAll: self fullname;
			nextPutAll: ' <';
			nextPutAll: self email;
			nextPutAll: '>'! !

Object subclass: #MOOCContactBook
	instanceVariableNames: 'contacts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MOOCContactBook'!

!MOOCContactBook commentStamp: 'RichardMyatt 7/25/2017 18:56' prior: 0!
I am a Contact Book which holds contacts.

This is an example taken from the Pharo MOOC.!

!MOOCContactBook class methodsFor: 'demos' stamp: 'RichardMyatt 7/27/2017 22:22'!
createDemoContactBook
	"create a set of demo contacts and populate a Contact Book
	 for testing purposes"

	| contact1 contact2 contact3 contact4 contact5 addressBook |
	contact1 := MOOCContact newNamed: 'Clara Allende' email: 'clari.allende@gmail.com'.
	contact2 := MOOCContact newNamed: 'Damien Cassou' email: 'damien@cassou.me'.
	contact3 := MOOCContact newNamed: 'Marcus Denker' email: 'marcus.denker@inria.fr'.
	contact4 := MOOCContact newNamed: 'Tudo Girba' email: 'tudor@tudorgirba.com'.
	contact5 := MOOCContact newNamed: 'Ruth Myatt' email: 'cooks_56@hotmail.com'.
	addressBook := MOOCContactBook new
										addContact: contact1;
										addContact: contact2;
										addContact: contact3;
										addContact: contact4;
										addContact: contact5.
	^ addressBook! !

!MOOCContactBook methodsFor: 'action' stamp: 'RichardMyatt 7/25/2017 19:00'!
addContact: aContact
	"add a contact to the address book"

	self contacts add: aContact! !

!MOOCContactBook methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 18:59'!
contacts
	"a form of lazy initialization"

	^ contacts ifNil: [ contacts := OrderedCollection new ]! !

!MOOCContactBook methodsFor: 'action' stamp: 'RichardMyatt 7/25/2017 19:01'!
removeContact: aContact
	"remove a contact from the address book"

	self contacts remove: aContact! !

WebContactBook initialize!
